function varargout = svd_selection(varargin)
% SVD_SELECTION MATLAB code for svd_selection.fig
%      SVD_SELECTION, by itself, creates a new SVD_SELECTION or raises the existing
%      singleton*.
%
%      H = SVD_SELECTION returns the handle to a new SVD_SELECTION or the handle to
%      the existing singleton*.
%
%      SVD_SELECTION('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in SVD_SELECTION.M with the given input arguments.
%
%      SVD_SELECTION('Property','Value',...) creates a new SVD_SELECTION or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before svd_selection_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to svd_selection_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help svd_selection

% Last Modified by GUIDE v2.5 13-Apr-2015 12:53:34

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @svd_selection_OpeningFcn, ...
                   'gui_OutputFcn',  @svd_selection_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before svd_selection is made visible.
function svd_selection_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to svd_selection (see VARARGIN)

% Choose default command line output for svd_selection
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes svd_selection wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = svd_selection_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes during object creation, after setting all properties.
function edit_svd_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_svd (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit_svd_Callback(hObject, eventdata, handles)
% hObject    handle to edit_svd (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_svd as text
%        str2double(get(hObject,'String')) returns contents of edit_svd as a double


nrsvd=str2num(get(hObject,'String'));
assignin('base','nrsvd',nrsvd);
evalin('base','mcr_als.aux.nrsvd=nrsvd;');
evalin('base','clear nrsvd');


% --- Executes on button press in push_cont.
function push_cont_Callback(hObject, eventdata, handles)
% hObject    handle to push_cont (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
evalin('base','mcr_als.aux.estat_svd=0;');
close;

% warndlg('Use the Close button to close this window.');
